@@ -17,7 +17,7 @@
 #ifndef RSIBREAK_RSITIMER_TEST_H
 #define RSIBREAK_RSITIMER_TEST_H
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 class RSITimerTest: public QObject
 {
@@ -35,6 +35,8 @@ private slots:
     void postponeBreak();
     void screenLock();
     void skipBreak();
+    void noPopupBreak();
+    void regularBreaks();
 };
 
 #endif //RSIBREAK_RSITIMER_TEST_H
